@@ -1,21 +1,21 @@
-/* Copyright (C) 1996, 1998, 2000, 2001, 2004, 2005, 2006, 2008, 2009,
- *   2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1996,1998,2000-2001,2004-2006,2008-2015,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -26,22 +26,30 @@
 # include <config.h>
 #endif
 
-#include "libguile/_scm.h"
-#include "libguile/strings.h"
-#include "libguile/arrays.h"
-#include "libguile/smob.h"
-#include "libguile/chars.h"
-#include "libguile/eq.h"
-#include "libguile/eval.h"
-#include "libguile/feature.h"
-#include "libguile/vectors.h"
-#include "libguile/bitvectors.h"
-#include "libguile/srfi-4.h"
-#include "libguile/generalized-arrays.h"
-
-#include "libguile/validate.h"
-#include "libguile/array-map.h"
 #include <assert.h>
+#include <string.h>
+
+#include "arrays.h"
+#include "bitvectors.h"
+#include "boolean.h"
+#include "chars.h"
+#include "eq.h"
+#include "eval.h"
+#include "feature.h"
+#include "generalized-arrays.h"
+#include "gsubr.h"
+#include "list.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "procs.h"
+#include "smob.h"
+#include "srfi-4.h"
+#include "strings.h"
+#include "symbols.h"
+#include "vectors.h"
+
+#include "array-map.h"
+
 
 /* The WHAT argument for `scm_gc_malloc ()' et al.  */
 static const char vi_gc_hint[] = "array-indices";
@@ -85,6 +93,7 @@ cindk (SCM ra, ssize_t *ve, int kend)
 
 #define LBND(ra, k) SCM_I_ARRAY_DIMS (ra)[k].lbnd
 #define UBND(ra, k) SCM_I_ARRAY_DIMS (ra)[k].ubnd
+#define MAX(A, B) ((A) >= (B) ? (A) : (B))
 
 
 /* scm_ramapc() always calls cproc with rank-1 arrays created by
@@ -107,7 +116,7 @@ scm_ramapc (void *cproc_ptr, SCM data, SCM ra0, SCM lra, const char *what)
       va0 = make1array (SCM_I_ARRAY_V (ra0), inc);
 
       /* Find unroll depth */
-      for (kroll = max(0, kmax); kroll > 0; --kroll)
+      for (kroll = MAX (0, kmax); kroll > 0; --kroll)
         {
           inc *= (UBND (ra0, kroll) - LBND (ra0, kroll) + 1);
           if (inc != SCM_I_ARRAY_DIMS (ra0)[kroll-1].inc)
@@ -263,6 +272,8 @@ racp (SCM src, SCM dst)
     {
       SCM const * el_s = h_s.elements;
       SCM * el_d = h_d.writable_elements;
+      if (!el_d && n>0)
+        scm_wrong_type_arg_msg ("array-copy!", SCM_ARG2, dst, "mutable array");
       for (; n-- > 0; i_s += inc_s, i_d += inc_d)
         el_d[i_d] = el_s[i_s];
     }
@@ -655,7 +666,7 @@ scm_i_array_rebase (SCM a, size_t base)
 
 static inline size_t padtoptr(size_t d) { return (d + (sizeof (void *) - 1)) & ~(sizeof (void *) - 1); }
 
-SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
+SCM_DEFINE (scm_array_slice_for_each, "array-slice-for-each", 2, 0, 1,
             (SCM frame_rank, SCM op, SCM args),
             "Apply @var{op} to each of the cells of rank rank(@var{arg})-@var{frame_rank}\n"
             "of the arrays @var{args}, in unspecified order. The first\n"
@@ -665,18 +676,19 @@ SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
             "For example:\n"
             "@lisp\n"
             ";; Sort the rows of rank-2 array A.\n\n"
-            "(array-for-each-cell 1 (lambda (x) (sort! x <)) a)\n"
+            "(array-slice-for-each 1 (lambda (x) (sort! x <)) a)\n"
             "\n"
             ";; Compute the arguments of the (x y) vectors in the rows of rank-2\n"
             ";; array XYS and store them in rank-1 array ANGLES. Inside OP,\n"
             ";; XY is a rank-1 (2-1) array, and ANGLE is a rank-0 (1-1) array.\n\n"
-            "(array-for-each-cell 1 \n"
+            "(array-slice-for-each 1 \n"
             "  (lambda (xy angle)\n"
             "    (array-set! angle (atan (array-ref xy 1) (array-ref xy 0))))\n"
             "  xys angles)\n"
             "@end lisp")
-#define FUNC_NAME s_scm_array_for_each_cell
+#define FUNC_NAME s_scm_array_slice_for_each
 {
+  SCM xargs = args;
   int const N = scm_ilength (args);
   int const frank = scm_to_int (frame_rank);
   int ocd;
@@ -740,9 +752,9 @@ SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
   assert((pool0+pool_size==pool) && "internal error");
 #undef AFIC_ALLOC_ADVANCE
 
-  for (n=0; scm_is_pair(args); args=scm_cdr(args), ++n)
+  for (n=0, xargs=args; scm_is_pair(xargs); xargs=scm_cdr(xargs), ++n)
     {
-      args_[n] = scm_car(args);
+      args_[n] = scm_car(xargs);
       scm_array_get_handle(args_[n], ah+n);
       as[n] = scm_array_handle_dims(ah+n);
       rank[n] = scm_array_handle_rank(ah+n);
@@ -750,29 +762,24 @@ SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
   /* checks */
   msg = NULL;
   if (frank<0)
-    msg = "bad frame rank";
+    msg = "bad frame rank ~S, ~S";
   else
     {
       for (n=0; n!=N; ++n)
         {
           if (rank[n]<frank)
             {
-              msg = "frame too large for arguments";
+              msg = "frame too large for arguments: ~S, ~S";
               goto check_msg;
             }
           for (k=0; k!=frank; ++k)
             {
-              if (as[n][k].lbnd!=0)
+              if (as[0][k].lbnd!=as[n][k].lbnd || as[0][k].ubnd!=as[n][k].ubnd)
                 {
-                  msg = "non-zero base index is not supported";
+                  msg = "mismatched frames: ~S, ~S";
                   goto check_msg;
                 }
-              if (as[0][k].ubnd!=as[n][k].ubnd)
-                {
-                  msg = "mismatched frames";
-                  goto check_msg;
-                }
-              s[k] = as[n][k].ubnd + 1;
+              s[k] = as[n][k].ubnd - as[n][k].lbnd + 1;
 
               /* this check is needed if the array cannot be entirely */
               /* unrolled, because the unrolled subloop will be run before */
@@ -787,7 +794,7 @@ SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
     {
       for (n=0; n!=N; ++n)
         scm_array_handle_release(ah+n);
-      scm_misc_error("array-for-each-cell", msg, scm_cons_star(frame_rank, args));
+      scm_misc_error("array-slice-for-each", msg, scm_cons(frame_rank, args));
     }
   /* prepare moving cells. */
   for (n=0; n!=N; ++n)
@@ -884,13 +891,13 @@ SCM_DEFINE (scm_array_for_each_cell, "array-for-each-cell", 2, 0, 1,
 }
 #undef FUNC_NAME
 
-SCM_DEFINE (scm_array_for_each_cell_in_order, "array-for-each-cell-in-order", 2, 0, 1,
+SCM_DEFINE (scm_array_slice_for_each_in_order, "array-slice-for-each-in-order", 2, 0, 1,
             (SCM frank, SCM op, SCM a),
-            "Same as array-for-each-cell, but visit the cells sequentially\n"
+            "Same as array-slice-for-each, but visit the cells sequentially\n"
             "and in row-major order.\n")
-#define FUNC_NAME s_scm_array_for_each_cell_in_order
+#define FUNC_NAME s_scm_array_slice_for_each_in_order
 {
-  return scm_array_for_each_cell (frank, op, a);
+  return scm_array_slice_for_each (frank, op, a);
 }
 #undef FUNC_NAME
 
@@ -898,12 +905,6 @@ SCM_DEFINE (scm_array_for_each_cell_in_order, "array-for-each-cell-in-order", 2,
 void
 scm_init_array_map (void)
 {
-#include "libguile/array-map.x"
+#include "array-map.x"
   scm_add_feature (s_scm_array_for_each);
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
