@@ -1,47 +1,48 @@
-/* Copyright (C) 1995,1996,1997,1998,2000,2001, 2002, 2004, 2006, 2008,
- *   2009, 2010, 2011, 2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-1998,2000-2002,2004,2006,2008-2011,2014,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
+
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+# include <config.h>
 #endif
 
-#include "libguile/_scm.h"
-#include "libguile/atomics-internal.h"
-#include "libguile/eval.h"
-#include "libguile/throw.h"
-#include "libguile/smob.h"
-#include "libguile/dynwind.h"
-#include "libguile/deprecation.h"
-
-#include "libguile/validate.h"
-#include "libguile/async.h"
-
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
-#include <unistd.h>
-
 #include <full-write.h>
+#include <string.h>
+#include <unistd.h>
+
+#include "atomics-internal.h"
+#include "deprecation.h"
+#include "dynwind.h"
+#include "eval.h"
+#include "gsubr.h"
+#include "list.h"
+#include "pairs.h"
+#include "smob.h"
+#include "throw.h"
+
+#include "async.h"
+
 
 
+
 /* {Asynchronous Events}
  *
  * Asyncs are used to run arbitrary code at the next safe point in a
@@ -55,7 +56,7 @@
  */
 
 void
-scm_i_async_push (scm_i_thread *t, SCM proc)
+scm_i_async_push (scm_thread *t, SCM proc)
 {
   SCM asyncs;
 
@@ -101,7 +102,7 @@ scm_i_async_push (scm_i_thread *t, SCM proc)
 
 /* Precondition: there are pending asyncs.  */
 SCM
-scm_i_async_pop (scm_i_thread *t)
+scm_i_async_pop (scm_thread *t)
 {
   while (1)
     {
@@ -139,7 +140,7 @@ scm_i_async_pop (scm_i_thread *t)
 void
 scm_async_tick (void)
 {
-  scm_i_thread *t = SCM_I_CURRENT_THREAD;
+  scm_thread *t = SCM_I_CURRENT_THREAD;
 
   if (t->block_asyncs)
     return;
@@ -149,32 +150,86 @@ scm_async_tick (void)
 }
 
 struct scm_thread_wake_data {
-  scm_i_pthread_mutex_t *mutex;
-  int fd;
+  enum { WAIT_FD, WAIT_COND } kind;
+  union {
+    struct {
+      int fd;
+    } wait_fd;
+    struct {
+      scm_i_pthread_mutex_t *mutex;
+      scm_i_pthread_cond_t *cond;
+    } wait_cond;
+  } data;
 };
 
 int
-scm_i_setup_sleep (scm_i_thread *t,
-		   scm_i_pthread_mutex_t *sleep_mutex,
-		   int sleep_fd)
+scm_i_prepare_to_wait (scm_thread *t,
+                       struct scm_thread_wake_data *wake)
 {
-  struct scm_thread_wake_data *wake;
-
-  wake = scm_gc_typed_calloc (struct scm_thread_wake_data);
-  wake->mutex = sleep_mutex;
-  wake->fd = sleep_fd;
+  if (t->block_asyncs)
+    return 0;
 
   scm_atomic_set_pointer ((void **)&t->wake, wake);
 
-  return !scm_is_null (scm_atomic_ref_scm (&t->pending_asyncs));
+  /* If no interrupt was registered in the meantime, then any future
+     wakeup will signal the FD or cond var.  */
+  if (scm_is_null (scm_atomic_ref_scm (&t->pending_asyncs)))
+    return 0;
+
+  /* Otherwise clear the wake pointer and indicate that the caller
+     should handle interrupts directly.  */
+  scm_i_wait_finished (t);
+  return 1;
 }
 
 void
-scm_i_reset_sleep (scm_i_thread *t)
+scm_i_wait_finished (scm_thread *t)
 {
   scm_atomic_set_pointer ((void **)&t->wake, NULL);
 }
 
+int
+scm_i_prepare_to_wait_on_fd (scm_thread *t, int fd)
+{
+  struct scm_thread_wake_data *wake;
+  wake = scm_gc_typed_calloc (struct scm_thread_wake_data);
+  wake->kind = WAIT_FD;
+  wake->data.wait_fd.fd = fd;
+  return scm_i_prepare_to_wait (t, wake);
+}
+
+int
+scm_c_prepare_to_wait_on_fd (int fd)
+{
+  return scm_i_prepare_to_wait_on_fd (SCM_I_CURRENT_THREAD, fd);
+}
+
+int
+scm_i_prepare_to_wait_on_cond (scm_thread *t,
+                               scm_i_pthread_mutex_t *m,
+                               scm_i_pthread_cond_t *c)
+{
+  struct scm_thread_wake_data *wake;
+  wake = scm_gc_typed_calloc (struct scm_thread_wake_data);
+  wake->kind = WAIT_COND;
+  wake->data.wait_cond.mutex = m;
+  wake->data.wait_cond.cond = c;
+  return scm_i_prepare_to_wait (t, wake);
+}
+
+int
+scm_c_prepare_to_wait_on_cond (scm_i_pthread_mutex_t *m,
+                               scm_i_pthread_cond_t *c)
+{
+  return scm_i_prepare_to_wait_on_cond (SCM_I_CURRENT_THREAD, m, c);
+}
+
+void
+scm_c_wait_finished (void)
+{
+  scm_i_wait_finished (SCM_I_CURRENT_THREAD);
+}
+
 SCM_DEFINE (scm_system_async_mark_for_thread, "system-async-mark", 1, 1, 0,
            (SCM proc, SCM thread),
 	    "Mark @var{proc} (a procedure with zero arguments) for future execution\n"
@@ -187,7 +242,7 @@ SCM_DEFINE (scm_system_async_mark_for_thread, "system-async-mark", 1, 1, 0,
 	    "signal handlers.")
 #define FUNC_NAME s_scm_system_async_mark_for_thread
 {
-  scm_i_thread *t;
+  scm_thread *t;
   struct scm_thread_wake_data *wake;
 
   if (SCM_UNBNDP (thread))
@@ -195,8 +250,6 @@ SCM_DEFINE (scm_system_async_mark_for_thread, "system-async-mark", 1, 1, 0,
   else
     {
       SCM_VALIDATE_THREAD (2, thread);
-      if (scm_c_thread_exited_p (thread))
-	SCM_MISC_ERROR ("thread has already exited", SCM_EOL);
       t = SCM_I_THREAD_DATA (thread);
     }
 
@@ -210,19 +263,18 @@ SCM_DEFINE (scm_system_async_mark_for_thread, "system-async-mark", 1, 1, 0,
 	 might even be in the next, unrelated sleep.  Interrupting it
 	 anyway does no harm, however.
 
-	 The important thing to prevent here is to signal sleep_cond
-	 before T waits on it.  This can not happen since T has
-	 sleep_mutex locked while setting t->sleep_mutex and will only
-	 unlock it again while waiting on sleep_cond.
+	 The important thing to prevent here is to signal the cond
+	 before T waits on it.  This can not happen since T has its
+	 mutex locked while preparing the wait and will only unlock it
+	 again while waiting on the cond.
       */
-      if (wake->mutex)
+      if (wake->kind == WAIT_COND)
         {
-          scm_i_scm_pthread_mutex_lock (wake->mutex);
-          scm_i_pthread_cond_signal (&t->sleep_cond);
-          scm_i_pthread_mutex_unlock (wake->mutex);
+          scm_i_scm_pthread_mutex_lock (wake->data.wait_cond.mutex);
+          scm_i_pthread_cond_signal (wake->data.wait_cond.cond);
+          scm_i_pthread_mutex_unlock (wake->data.wait_cond.mutex);
         }
-
-      if (wake->fd >= 0)
+      else if (wake->kind == WAIT_FD)
         {
           char dummy = 0;
 
@@ -231,8 +283,10 @@ SCM_DEFINE (scm_system_async_mark_for_thread, "system-async-mark", 1, 1, 0,
              not yet have started sleeping, but this is no problem
              either since the data written to a pipe will not be lost,
              unlike a condition variable signal.  */
-          full_write (wake->fd, &dummy, 1);
+          full_write (wake->data.wait_fd.fd, &dummy, 1);
         }
+      else
+        abort ();
     }
 
   return SCM_UNSPECIFIED;
@@ -267,14 +321,14 @@ SCM_DEFINE (scm_noop, "noop", 0, 0, 1,
 static void
 increase_block (void *data)
 {
-  scm_i_thread *t = data;
+  scm_thread *t = data;
   t->block_asyncs++;
 }
 
 static void
 decrease_block (void *data)
 {
-  scm_i_thread *t = data;
+  scm_thread *t = data;
   if (--t->block_asyncs == 0)
     scm_async_tick ();
 }
@@ -282,7 +336,7 @@ decrease_block (void *data)
 void
 scm_dynwind_block_asyncs (void)
 {
-  scm_i_thread *t = SCM_I_CURRENT_THREAD;
+  scm_thread *t = SCM_I_CURRENT_THREAD;
   scm_dynwind_rewind_handler (increase_block, t, SCM_F_WIND_EXPLICITLY);
   scm_dynwind_unwind_handler (decrease_block, t, SCM_F_WIND_EXPLICITLY);
 }
@@ -290,7 +344,7 @@ scm_dynwind_block_asyncs (void)
 void
 scm_dynwind_unblock_asyncs (void)
 {
-  scm_i_thread *t = SCM_I_CURRENT_THREAD;
+  scm_thread *t = SCM_I_CURRENT_THREAD;
   if (t->block_asyncs == 0)
     scm_misc_error ("scm_with_unblocked_asyncs", 
 		    "asyncs already unblocked", SCM_EOL);
@@ -373,11 +427,5 @@ scm_c_call_with_unblocked_asyncs (void *(*proc) (void *data), void *data)
 void
 scm_init_async ()
 {
-#include "libguile/async.x"
+#include "async.x"
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
