@@ -1,38 +1,44 @@
-/* Copyright (C) 1995,1996,1998, 2000, 2001, 2004, 2006, 2008, 2009,
- *   2010, 2011, 2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-1996,1998,2000-2001,2004,2006,2008-2011,2014,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
+
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <ctype.h>
 #include <limits.h>
+#include <string.h>
 #include <unicase.h>
 #include <unictype.h>
 
-#include "libguile/_scm.h"
-#include "libguile/validate.h"
+#include "boolean.h"
+#include "gsubr.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "srfi-14.h"
+#include "symbols.h"
+
+#include "chars.h"
 
-#include "libguile/chars.h"
-#include "libguile/srfi-14.h"
 
 
 
@@ -536,7 +542,7 @@ static const char *const scm_r5rs_charnames[] = {
   "space", "newline"
 };
 
-static const scm_t_uint32 scm_r5rs_charnums[] = {
+static const uint32_t scm_r5rs_charnums[] = {
   0x20, 0x0a
 };
 
@@ -548,7 +554,7 @@ static const char *const scm_r6rs_charnames[] = {
   /* 'space' and 'newline' are already included from the R5RS list.  */
 };
 
-static const scm_t_uint32 scm_r6rs_charnums[] = {
+static const uint32_t scm_r6rs_charnums[] = {
   0x00, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c,
   0x0d, 0x1b, 0x7f
 };
@@ -559,7 +565,7 @@ static const char *const scm_r7rs_charnames[] = {
   "escape"
 };
 
-static const scm_t_uint32 scm_r7rs_charnums[] = {
+static const uint32_t scm_r7rs_charnums[] = {
   0x1b
 };
 
@@ -575,7 +581,7 @@ static const char *const scm_C0_control_charnames[] = {
   "sp", "del"
 };
 
-static const scm_t_uint32 scm_C0_control_charnums[] = {
+static const uint32_t scm_C0_control_charnums[] = {
   0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
   0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
   0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
@@ -589,7 +595,7 @@ static const char *const scm_alt_charnames[] = {
   "null", "nl", "np"
 };
 
-static const scm_t_uint32 scm_alt_charnums[] = {
+static const uint32_t scm_alt_charnums[] = {
   0x00, 0x0a, 0x0c
 };
 
@@ -601,7 +607,7 @@ const char *
 scm_i_charname (SCM chr)
 {
   size_t c;
-  scm_t_uint32 i = SCM_CHAR (chr);
+  uint32_t i = SCM_CHAR (chr);
 
   for (c = 0; c < SCM_N_R5RS_CHARNAMES; c++)
     if (scm_r5rs_charnums[c] == i)
@@ -676,12 +682,6 @@ scm_i_charname_to_char (const char *charname, size_t charname_len)
 void
 scm_init_chars ()
 {
-#include "libguile/chars.x"
+#include "chars.x"
 }
 
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
