@@ -1,21 +1,21 @@
-/* Copyright (C) 2000-2002, 2004, 2006, 2008, 2009, 2018
- *   Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 2000,2006,2008,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -24,11 +24,13 @@
 #include <string.h>
 #include <stdio.h>
 
-#include "libguile/_scm.h"
-#include "libguile/alist.h"
-#include "libguile/strings.h"
+#include "alist.h"
+#include "gsubr.h"
+#include "numbers.h"
+#include "strings.h"
+
+#include "debug-malloc.h"
 
-#include "libguile/debug-malloc.h"
 
 /*
  * The following code is a hack which I wrote quickly in order to
@@ -222,7 +224,7 @@ SCM_DEFINE (scm_malloc_stats, "malloc-stats", 0, 0, 0,
   int i;
   for (i = 0; i < malloc_type_size + N_SEEK; ++i)
     if (malloc_type[i].key)
-      res = scm_acons (scm_from_utf8_string ((char *) malloc_type[i].key),
+      res = scm_acons (scm_from_locale_string ((char *) malloc_type[i].key),
 		       scm_from_int ((int) malloc_type[i].data),
 		       res);
   return res;
@@ -243,6 +245,6 @@ scm_debug_malloc_prehistory ()
 void
 scm_init_debug_malloc ()
 {
-#include "libguile/debug-malloc.x"
+#include "debug-malloc.x"
 }
 
