@@ -1,21 +1,21 @@
-/* Copyright (C) 1995,1996,1997,1998,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2014
- * Free Software Foundation, Inc.
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-1996,1997-2014,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -23,20 +23,27 @@
 #  include <config.h>
 #endif
 
-#include "libguile/__scm.h"
-#include "libguile/_scm.h"
-#include "libguile/continuations.h"
-#include "libguile/eq.h"
-#include "libguile/list.h"
-#include "libguile/macros.h"
-#include "libguile/expand.h"
-#include "libguile/modules.h"
-#include "libguile/srcprop.h"
-#include "libguile/ports.h"
-#include "libguile/print.h"
-#include "libguile/strings.h"
-#include "libguile/throw.h"
-#include "libguile/validate.h"
+#include "alist.h"
+#include "boolean.h"
+#include "continuations.h"
+#include "eq.h"
+#include "gsubr.h"
+#include "hashtab.h"
+#include "keywords.h"
+#include "list.h"
+#include "macros.h"
+#include "modules.h"
+#include "pairs.h"
+#include "ports.h"
+#include "print.h"
+#include "srcprop.h"
+#include "strings.h"
+#include "symbols.h"
+#include "throw.h"
+#include "variable.h"
+#include "vectors.h"
+
+#include "expand.h"
 
 
 
@@ -109,27 +116,18 @@ static const char s_bad_expression[] = "Bad expression";
 static const char s_expression[] = "Missing or extra expression in";
 static const char s_missing_expression[] = "Missing expression in";
 static const char s_extra_expression[] = "Extra expression in";
-static const char s_empty_combination[] = "Illegal empty combination";
-static const char s_missing_body_expression[] = "Missing body expression in";
-static const char s_mixed_body_forms[] = "Mixed definitions and expressions in";
 static const char s_bad_define[] = "Bad define placement";
 static const char s_missing_clauses[] = "Missing clauses";
 static const char s_misplaced_else_clause[] = "Misplaced else clause";
-static const char s_bad_case_clause[] = "Bad case clause";
-static const char s_bad_case_labels[] = "Bad case labels";
-static const char s_duplicate_case_label[] = "Duplicate case label";
 static const char s_bad_cond_clause[] = "Bad cond clause";
 static const char s_missing_recipient[] = "Missing recipient in";
 static const char s_bad_variable[] = "Bad variable";
 static const char s_bad_bindings[] = "Bad bindings";
 static const char s_bad_binding[] = "Bad binding";
 static const char s_duplicate_binding[] = "Duplicate binding";
-static const char s_bad_exit_clause[] = "Bad exit clause";
 static const char s_bad_formals[] = "Bad formals";
 static const char s_bad_formal[] = "Bad formal";
 static const char s_duplicate_formal[] = "Duplicate formal";
-static const char s_splicing[] = "Non-list result for unquote-splicing";
-static const char s_bad_slot_number[] = "Bad slot number";
 
 static void syntax_error (const char* const, const SCM, const SCM) SCM_NORETURN;
 
@@ -1657,11 +1655,5 @@ scm_init_expand ()
 
   scm_c_define ("%expanded-vtables", scm_vector (exp_vtable_list));
   
-#include "libguile/expand.x"
+#include "expand.x"
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
