@@ -1,21 +1,21 @@
-/* Copyright (C) 1996-2002, 2004, 2006, 2009-2019
- *   Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1996-2002,2004,2006,2009-2014,2016-2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -32,37 +32,26 @@
 #endif
 
 #include <alloca.h>
+#include <dirent.h>
 #include <dirname.h>
-
-#include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
-
-#include "libguile/_scm.h"
-#include "libguile/smob.h"
-#include "libguile/fdes-finalizers.h"
-#include "libguile/feature.h"
-#include "libguile/fports.h"
-#include "libguile/strings.h"
-#include "libguile/iselect.h"
-#include "libguile/vectors.h"
-#include "libguile/dynwind.h"
-#include "libguile/ports.h"
-#include "libguile/ports-internal.h"
-
-#include "libguile/validate.h"
-#include "libguile/filesys.h"
-#include "libguile/load.h"	/* for scm_i_mirror_backslashes */
-
-
-#ifdef HAVE_IO_H
-#include <io.h>
-#endif
+#include <fcntl.h>
+#include <full-read.h>
+#include <full-write.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 #ifdef HAVE_DIRECT_H
 #include <direct.h>
 #endif
 
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
+
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -74,8 +63,6 @@
 # endif
 #endif
 
-#include <unistd.h>
-
 #ifdef LIBC_H_WITH_UNISTD_H
 #include <libc.h>
 #endif
@@ -84,29 +71,48 @@
 #include <string.h>
 #endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
 
-#include <dirent.h>
-
-#define NAMLEN(dirent)  strlen ((dirent)->d_name)
-
 #ifdef HAVE_SYS_SENDFILE_H
 # include <sys/sendfile.h>
 #endif
 
+#include "async.h"
+#include "boolean.h"
+#include "dynwind.h"
+#include "fdes-finalizers.h"
+#include "feature.h"
+#include "fports.h"
+#include "gsubr.h"
+#include "iselect.h"
+#include "list.h"
+#include "load.h"	/* for scm_i_mirror_backslashes */
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "ports-internal.h"
+#include "ports.h"
+#include "posix.h"
+#include "smob.h"
+#include "srfi-13.h"
+#include "strings.h"
+#include "symbols.h"
+#include "syscalls.h"
+#include "vectors.h"
+
+#include "filesys.h"
+
+
+
+
+#define NAMLEN(dirent)  strlen ((dirent)->d_name)
+
 /* Glibc's `sendfile' function.  */
 #define sendfile_or_sendfile64			\
   CHOOSE_LARGEFILE (sendfile, sendfile64)
 
-#include <full-read.h>
-#include <full-write.h>
-
 
 
 
@@ -1507,9 +1513,9 @@ SCM_DEFINE (scm_i_mkstemp, "mkstemp!", 1, 1, 0,
       /* mkostemp(2) only defines O_APPEND, O_SYNC, and O_CLOEXEC to be
          useful, as O_RDWR|O_CREAT|O_EXCL are implicitly added.  It also
          notes that other flags may error on some systems, which turns
-         out to be the case.  Of those flags, O_APPEND and O_BINARY are
-         the only ones of interest anyway, so limit to those flags.  */
-      open_flags &= O_APPEND | O_BINARY;
+         out to be the case.  Of those flags, O_APPEND is the only one
+         of interest anyway, so limit to that flag.  */
+      open_flags &= O_APPEND;
       mode_bits = scm_i_mode_bits (mode);
     }
 
@@ -1602,20 +1608,11 @@ SCM_DEFINE (scm_basename, "basename", 1, 1, 0,
   c_filename = scm_to_utf8_string (filename);
   scm_dynwind_free (c_filename);
 
-  if (strcmp (c_filename, "/") == 0
-      || strcmp (c_filename, "//") == 0)
-    /* As per
-       <http://pubs.opengroup.org/onlinepubs/9699919799/functions/basename.html>,
-       "/" and "//" are treated specially.  */
-    res = scm_from_utf8_string ("/");
+  c_last_component = last_component (c_filename);
+  if (!c_last_component)
+    res = filename;
   else
-    {
-      c_last_component = last_component (c_filename);
-      if (!c_last_component)
-        res = filename;
-      else
-        res = scm_from_utf8_string (c_last_component);
-    }
+    res = scm_from_utf8_string (c_last_component);
   scm_dynwind_end ();
 
   if (!SCM_UNBNDP (suffix) &&
@@ -1954,13 +1951,7 @@ scm_init_filesys ()
   scm_c_define ("X_OK", scm_from_int (X_OK));
   scm_c_define ("F_OK", scm_from_int (F_OK));
 
-  scm_dot_string = scm_from_utf8_string (".");
+  scm_dot_string = scm_from_locale_string (".");
 
-#include "libguile/filesys.x"
+#include "filesys.x"
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
