@@ -1,38 +1,27 @@
-/* Copyright (C) 2006-2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 2006-2014,2017-2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <alloca.h>
-
-#include "libguile/_scm.h"
-#include "libguile/extensions.h"
-#include "libguile/feature.h"
-#include "libguile/i18n.h"
-#include "libguile/strings.h"
-#include "libguile/chars.h"
-#include "libguile/dynwind.h"
-#include "libguile/validate.h"
-#include "libguile/values.h"
-#include "libguile/threads.h"
-
 #include <locale.h>
 #include <string.h> /* `strcoll ()' */
 #include <ctype.h>  /* `toupper ()' et al. */
@@ -40,6 +29,28 @@
 #include <unicase.h>
 #include <unistr.h>
 
+#include "boolean.h"
+#include "chars.h"
+#include "dynwind.h"
+#include "extensions.h"
+#include "feature.h"
+#include "gsubr.h"
+#include "list.h"
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "posix.h"  /* for `scm_i_locale_mutex' */
+#include "smob.h"
+#include "strings.h"
+#include "symbols.h"
+#include "syscalls.h"
+#include "threads.h"
+#include "values.h"
+#include "variable.h"
+#include "version.h"
+
+#include "i18n.h"
+
 #if defined HAVE_NEWLOCALE && defined HAVE_STRCOLL_L && defined HAVE_USELOCALE
 /* The GNU thread-aware locale API is documented in ``Thread-Aware Locale
    Model, a Proposal'', by Ulrich Drepper:
@@ -57,8 +68,6 @@
 # define USE_GNU_LOCALE_API
 #endif
 
-#include "libguile/posix.h"  /* for `scm_i_locale_mutex' */
-
 /* Use Gnulib's header, which also provides `nl_item' & co.  */
 #include <langinfo.h>
 
@@ -755,11 +764,11 @@ compare_u32_strings (SCM s1, SCM s2, SCM locale, const char *func_name)
 
   if (c_locale)
     RUN_IN_LOCALE_SECTION (c_locale, 
-                           result = u32_strcoll ((const scm_t_uint32 *) c_s1, 
-                                                 (const scm_t_uint32 *) c_s2));
+                           result = u32_strcoll ((const uint32_t *) c_s1, 
+                                                 (const uint32_t *) c_s2));
   else
-    result = u32_strcoll ((const scm_t_uint32 *) c_s1,
-			  (const scm_t_uint32 *) c_s2);
+    result = u32_strcoll ((const uint32_t *) c_s1,
+			  (const uint32_t *) c_s2);
 
   scm_remember_upto_here_2 (s1, s2);
   scm_remember_upto_here (locale);
@@ -779,8 +788,8 @@ locale_language ()
 }
 
 static inline int
-u32_locale_casecoll (const char *func_name, const scm_t_uint32 *c_s1,
-                     const scm_t_uint32 *c_s2,
+u32_locale_casecoll (const char *func_name, const uint32_t *c_s1,
+                     const uint32_t *c_s2,
 		     int *result)
 {
   /* Note: Since this is called from `RUN_IN_LOCALE_SECTION', it must note
@@ -812,13 +821,13 @@ compare_u32_strings_ci (SCM s1, SCM s2, SCM locale, const char *func_name)
     RUN_IN_LOCALE_SECTION
       (c_locale,
        ret = u32_locale_casecoll (func_name,
-				  (const scm_t_uint32 *) c_s1,
-				  (const scm_t_uint32 *) c_s2,
+				  (const uint32_t *) c_s1,
+				  (const uint32_t *) c_s2,
 				  &result));
   else
     ret = u32_locale_casecoll (func_name,
-			       (const scm_t_uint32 *) c_s1,
-			       (const scm_t_uint32 *) c_s2,
+			       (const uint32_t *) c_s1,
+			       (const uint32_t *) c_s2,
 			       &result);
 
   if (SCM_UNLIKELY (ret != 0))
@@ -1036,16 +1045,16 @@ SCM_DEFINE (scm_char_locale_ci_eq, "char-locale-ci=?", 2, 1, 0,
 /* Locale-dependent alphabetic character mapping.  */
 
 static inline int
-u32_locale_tocase (const scm_t_uint32 *c_s1, size_t len,
-                   scm_t_uint32 **p_c_s2, size_t * p_len2,
-                   scm_t_uint32 *(*func) (const scm_t_uint32 *, size_t,
+u32_locale_tocase (const uint32_t *c_s1, size_t len,
+                   uint32_t **p_c_s2, size_t * p_len2,
+                   uint32_t *(*func) (const uint32_t *, size_t,
                                           const char *, uninorm_t,
-                                          scm_t_uint32 *, size_t *))
+                                          uint32_t *, size_t *))
 {
   /* Note: Since this is called from `RUN_IN_LOCALE_SECTION', it must not
      make any non-local exit.  */
 
-  scm_t_uint32 *ret;
+  uint32_t *ret;
   const char *loc = locale_language ();
 
   /* The first NULL here indicates that no NFC or NFKC normalization
@@ -1055,7 +1064,7 @@ u32_locale_tocase (const scm_t_uint32 *c_s1, size_t len,
 
   if (ret == NULL)
     {
-      *p_c_s2 = (scm_t_uint32 *) NULL;
+      *p_c_s2 = (uint32_t *) NULL;
       *p_len2 = 0;
       return errno;
     }
@@ -1067,15 +1076,15 @@ u32_locale_tocase (const scm_t_uint32 *c_s1, size_t len,
 
 static SCM
 chr_to_case (SCM chr, scm_t_locale c_locale, 
-	     scm_t_uint32 *(*func) (const scm_t_uint32 *, size_t, const char *,
-				    uninorm_t, scm_t_uint32 *, size_t *),
+	     uint32_t *(*func) (const uint32_t *, size_t, const char *,
+				    uninorm_t, uint32_t *, size_t *),
 	     const char *func_name,
 	     int *err)
 #define FUNC_NAME func_name
 {
   int ret;
-  scm_t_uint32 c;
-  scm_t_uint32 *convbuf;
+  uint32_t c;
+  uint32_t *convbuf;
   size_t convlen;
   SCM convchar;
 
@@ -1178,14 +1187,14 @@ SCM_DEFINE (scm_char_locale_titlecase, "char-locale-titlecase", 1, 1, 0,
 
 static SCM
 str_to_case (SCM str, scm_t_locale c_locale,
-	     scm_t_uint32 *(*func) (const scm_t_uint32 *, size_t, const char *,
-				    uninorm_t, scm_t_uint32 *, size_t *),
+	     uint32_t *(*func) (const uint32_t *, size_t, const char *,
+				    uninorm_t, uint32_t *, size_t *),
 	     const char *func_name,
 	     int *err)
 #define FUNC_NAME func_name
 {
   scm_t_wchar *c_str, *c_buf;
-  scm_t_uint32 *c_convstr;
+  uint32_t *c_convstr;
   size_t len, convlen;
   int ret;
   SCM convstr;
@@ -1197,12 +1206,12 @@ str_to_case (SCM str, scm_t_locale c_locale,
 
   if (c_locale)
     RUN_IN_LOCALE_SECTION (c_locale, ret =
-                           u32_locale_tocase ((scm_t_uint32 *) c_str, len,
+                           u32_locale_tocase ((uint32_t *) c_str, len,
                                               &c_convstr,
                                               &convlen, func));
   else
     ret =
-      u32_locale_tocase ((scm_t_uint32 *) c_str, len,
+      u32_locale_tocase ((uint32_t *) c_str, len,
                          &c_convstr, &convlen, func);
 
   scm_remember_upto_here (str);
@@ -1352,7 +1361,7 @@ SCM_DEFINE (scm_locale_string_to_integer, "locale-string->integer",
   else
     result = scm_from_long (c_result);
 
-  return (scm_values (scm_list_2 (result, scm_from_long (c_endptr - c_str))));
+  return scm_values_2 (result, scm_from_long (c_endptr - c_str));
 }
 #undef FUNC_NAME
 
@@ -1396,7 +1405,7 @@ SCM_DEFINE (scm_locale_string_to_inexact, "locale-string->inexact",
   else
     result = scm_from_double (c_result);
 
-  return (scm_values (scm_list_2 (result, scm_from_long (c_endptr - c_str))));
+  return scm_values_2 (result, scm_from_long (c_endptr - c_str));
 }
 #undef FUNC_NAME
 
@@ -1567,7 +1576,8 @@ SCM_DEFINE (scm_nl_langinfo, "nl-langinfo", 1, 1, 0,
 
 #if defined P_CS_PRECEDES || defined N_CS_PRECEDES ||	\
   defined INT_P_CS_PRECEDES || defined INT_N_CS_PRECEDES || \
-  defined P_SEP_BY_SPACE || defined N_SEP_BY_SPACE
+  defined P_SEP_BY_SPACE || defined N_SEP_BY_SPACE || \
+  defined INT_P_SEP_BY_SPACE || defined INT_N_SEP_BY_SPACE
 #ifdef P_CS_PRECEDES
 	case P_CS_PRECEDES:
 	case N_CS_PRECEDES:
@@ -1580,8 +1590,12 @@ SCM_DEFINE (scm_nl_langinfo, "nl-langinfo", 1, 1, 0,
 	case P_SEP_BY_SPACE:
 	case N_SEP_BY_SPACE:
 #endif
-	  /* This is to be interpreted as a boolean.  */
-	  result = scm_from_bool (*c_result);
+#ifdef INT_P_SEP_BY_SPACE
+        case INT_P_SEP_BY_SPACE:
+        case INT_N_SEP_BY_SPACE:
+#endif
+          /* This is to be interpreted as a boolean.  */
+          result = scm_from_bool (*c_result);
 
 	  free (c_result);
 	  break;
@@ -1822,7 +1836,7 @@ scm_init_i18n ()
   scm_add_feature ("nl-langinfo");
   define_langinfo_items ();
 
-#include "libguile/i18n.x"
+#include "i18n.x"
 
   /* Initialize the global locale object with a special `locale' SMOB.  */
   /* XXX: We don't define it as `LC_GLOBAL_LOCALE' because of bugs as of
@@ -1842,9 +1856,3 @@ scm_bootstrap_i18n ()
 
 }
 
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
