@@ -1,21 +1,21 @@
-/* Copyright (C) 1995,1996,2000,2001, 2004, 2005, 2006, 2008, 2009,
- *   2011, 2012, 2013 Free Software Foundation, Inc.
- * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-1996,2000-2001,2004-2006,2008-2009,2011-2013,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -23,12 +23,12 @@
 # include <config.h>
 #endif
 
-#include "libguile/_scm.h"
-#include "libguile/validate.h"
+#include <verify.h>
 
-#include "libguile/pairs.h"
+#include "boolean.h"
+#include "gsubr.h"
 
-#include "verify.h"
+#include "pairs.h"
 
 
 
@@ -41,7 +41,7 @@
  * which is defined in terms of the SCM_MATCHES_BITS_IN_COMMON macro.
  *
  * See the comments preceeding the definitions of SCM_BOOL_F and
- * SCM_MATCHES_BITS_IN_COMMON in tags.h for more information.
+ * SCM_MATCHES_BITS_IN_COMMON in scm.h for more information.
  */
 verify (SCM_BITS_DIFFER_IN_EXACTLY_ONE_BIT_POSITION		\
         (SCM_ELISP_NIL_BITS, SCM_EOL_BITS));
@@ -49,8 +49,8 @@ verify (SCM_BITS_DIFFER_IN_EXACTLY_ONE_BIT_POSITION		\
 
 #if (SCM_DEBUG_PAIR_ACCESSES == 1)
 
-#include "libguile/ports.h"
-#include "libguile/strings.h"
+#include "ports.h"
+#include "strings.h"
 
 void scm_error_pair_access (SCM non_pair)
 {
@@ -91,7 +91,7 @@ SCM_DEFINE (scm_set_car_x, "set-car!", 2, 0, 0,
             "by @code{set-car!} is unspecified.")
 #define FUNC_NAME s_scm_set_car_x
 {
-  SCM_VALIDATE_CONS (1, pair);
+  SCM_VALIDATE_MUTABLE_PAIR (1, pair);
   SCM_SETCAR (pair, value);
   return SCM_UNSPECIFIED;
 }
@@ -104,7 +104,7 @@ SCM_DEFINE (scm_set_cdr_x, "set-cdr!", 2, 0, 0,
             "by @code{set-cdr!} is unspecified.")
 #define FUNC_NAME s_scm_set_cdr_x
 {
-  SCM_VALIDATE_CONS (1, pair);
+  SCM_VALIDATE_MUTABLE_PAIR (1, pair);
   SCM_SETCDR (pair, value);
   return SCM_UNSPECIFIED;
 }
@@ -120,7 +120,7 @@ SCM_DEFINE (scm_set_cdr_x, "set-cdr!", 2, 0, 0,
 
 /* The compiler should unroll this. */
 #define CHASE_PAIRS(tree, FUNC_NAME, pattern)                           \
-  scm_t_uint32 pattern_var = pattern;                                   \
+  uint32_t pattern_var = pattern;                                   \
   do                                                                    \
     {                                                                   \
       if (!scm_is_pair (tree))                                          \
@@ -334,15 +334,9 @@ SCM_DEFINE (scm_caaaar, "caaaar", 1, 0, 0, (SCM x), "")
 void
 scm_init_pairs ()
 {
-#include "libguile/pairs.x"
+#include "pairs.x"
   scm_c_define_gsubr ("cons", 2, 0, 0, scm_cons);
   scm_c_define_gsubr ("car", 1, 0, 0, scm_car);
   scm_c_define_gsubr ("cdr", 1, 0, 0, scm_cdr);
 }
 
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
