@@ -1,22 +1,21 @@
-/* Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
- *   2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013,
- *   2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-2014,2016-2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -24,18 +23,20 @@
 #  include <config.h>
 #endif
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <uniconv.h>
+#include <unistd.h>
 
 #ifdef HAVE_SCHED_H
 # include <sched.h>
 #endif
 
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -47,44 +48,47 @@
 # endif
 #endif
 
-#include <unistd.h>
-
 #ifdef LIBC_H_WITH_UNISTD_H
-#include <libc.h>
+# include <libc.h>
 #endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-
 #ifdef HAVE_PWD_H
-#include <pwd.h>
+# include <pwd.h>
 #endif
 #ifdef HAVE_IO_H
-#include <io.h>
+# include <io.h>
 #endif
 
-#include "libguile/_scm.h"
-#include "libguile/dynwind.h"
-#include "libguile/fports.h"
-#include "libguile/scmsigs.h"
-#include "libguile/feature.h"
-#include "libguile/strings.h"
-#include "libguile/srfi-13.h"
-#include "libguile/srfi-14.h"
-#include "libguile/vectors.h"
-#include "libguile/values.h"
-
-#include "libguile/validate.h"
-#include "libguile/posix.h"
-#include "libguile/gettext.h"
-#include "libguile/threads.h"
-
-
 #ifdef __MINGW32__
 # include "posix-w32.h"
 #endif
 
+#include "async.h"
+#include "bitvectors.h"
+#include "dynwind.h"
+#include "extensions.h"
+#include "feature.h"
+#include "finalizers.h"
+#include "fports.h"
+#include "gettext.h"
+#include "gsubr.h"
+#include "list.h"
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "scmsigs.h"
+#include "srfi-13.h"
+#include "srfi-14.h"
+#include "strings.h"
+#include "symbols.h"
+#include "syscalls.h"
+#include "threads.h"
+#include "values.h"
+#include "vectors.h"
+#include "version.h"
+
+#include "posix.h"
+
 #if HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
@@ -596,10 +600,10 @@ SCM_DEFINE (scm_getrlimit, "getrlimit", 1, 0, 0,
   if (getrlimit (iresource, &lim) != 0)
     scm_syserror (FUNC_NAME);
 
-  return scm_values (scm_list_2 ((lim.rlim_cur == RLIM_INFINITY) ? SCM_BOOL_F
-                                 : scm_from_long (lim.rlim_cur),
-                                 (lim.rlim_max == RLIM_INFINITY) ? SCM_BOOL_F
-                                 : scm_from_long (lim.rlim_max)));
+  return scm_values_2 ((lim.rlim_cur == RLIM_INFINITY) ? SCM_BOOL_F
+                       : scm_from_long (lim.rlim_cur),
+                       (lim.rlim_max == RLIM_INFINITY) ? SCM_BOOL_F
+                       : scm_from_long (lim.rlim_max));
 }
 #undef FUNC_NAME
 
@@ -1432,9 +1436,7 @@ scm_open_process (SCM mode, SCM prog, SCM args)
                                        SCM_FPORT_OPTION_NOT_SEEKABLE);
     }
 
-  return scm_values (scm_list_3 (read_port,
-                                 write_port,
-                                 scm_from_int (pid)));
+  return scm_values_3 (read_port, write_port, scm_from_int (pid));
 }
 #undef FUNC_NAME
 
@@ -1489,10 +1491,12 @@ SCM_DEFINE (scm_system_star, "system*", 0, 0, 1,
 
   scm_dynwind_begin (0);
   /* Make sure the child can't kill us (as per normal system call).  */
-  scm_dynwind_sigaction (SIGINT, scm_from_long ((long) SIG_IGN),
+  scm_dynwind_sigaction (SIGINT,
+                         scm_from_uintptr_t ((uintptr_t) SIG_IGN),
                          SCM_UNDEFINED);
 #ifdef SIGQUIT
-  scm_dynwind_sigaction (SIGQUIT, scm_from_long ((long) SIG_IGN),
+  scm_dynwind_sigaction (SIGQUIT,
+                         scm_from_uintptr_t ((uintptr_t) SIG_IGN),
                          SCM_UNDEFINED);
 #endif
 
@@ -1933,26 +1937,46 @@ SCM_DEFINE (scm_crypt, "crypt", 2, 0, 0,
 	    "crypt(3) library call.")
 #define FUNC_NAME s_scm_crypt
 {
+  int err;
   SCM ret;
   char *c_key, *c_salt, *c_ret;
 
   scm_dynwind_begin (0);
-  scm_i_dynwind_pthread_mutex_lock (&scm_i_misc_mutex);
 
   c_key = scm_to_locale_string (key);
   scm_dynwind_free (c_key);
   c_salt = scm_to_locale_string (salt);
   scm_dynwind_free (c_salt);
 
+  /* Take the lock because 'crypt' uses a static buffer.  */
+  scm_i_dynwind_pthread_mutex_lock (&scm_i_misc_mutex);
+
   /* The Linux crypt(3) man page says crypt will return NULL and set errno
      on error.  (Eg. ENOSYS if legal restrictions mean it cannot be
      implemented).  */
   c_ret = crypt (c_key, c_salt);
-  if (c_ret == NULL)
-    SCM_SYSERROR;
 
-  ret = scm_from_locale_string (c_ret);
+  if (c_ret == NULL)
+    {
+      /* Note: Do not throw until we've released 'scm_i_misc_mutex'
+	 since this would cause a deadlock down the path.  */
+      err = errno;
+      ret = SCM_BOOL_F;
+    }
+  else
+    {
+      err = 0;
+      ret = scm_from_locale_string (c_ret);
+    }
+
   scm_dynwind_end ();
+
+  if (scm_is_false (ret))
+    {
+      errno = err;
+      SCM_SYSERROR;
+    }
+
   return ret;
 }
 #undef FUNC_NAME
@@ -2108,7 +2132,7 @@ SCM_DEFINE (scm_setaffinity, "setaffinity", 2, 0, 0,
 {
   cpu_set_t cs;
   scm_t_array_handle handle;
-  const scm_t_uint32 *c_mask;
+  const uint32_t *c_mask;
   size_t len, off, cpu;
   ssize_t inc;
   int err;
@@ -2411,8 +2435,8 @@ scm_init_posix ()
   scm_c_define ("LOCK_NB", scm_from_int (LOCK_NB));
 #endif
 
-#include "libguile/cpp-SIG.c"
-#include "libguile/posix.x"
+#include "cpp-SIG.c"
+#include "posix.x"
 
 #ifdef HAVE_FORK
   scm_add_feature ("fork");
@@ -2425,9 +2449,3 @@ scm_init_posix ()
 			    NULL);
 #endif /* HAVE_START_CHILD */
 }
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
