@@ -1,21 +1,21 @@
-/* Copyright (C) 1995,1996,1997,1998,1999,2000,2001, 2002, 2004, 2006,
- *   2007, 2008, 2009, 2011, 2013, 2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995-2002,2004,2006-2009,2011,2013-2014,2017-2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -41,15 +41,23 @@
 
 #include <full-write.h>
 
-#include "libguile/_scm.h"
+#include "async.h"
+#include "boolean.h"
+#include "dynwind.h"
+#include "eval.h"
+#include "feature.h"
+#include "gsubr.h"
+#include "list.h"
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "procs.h"
+#include "syscalls.h"
+#include "threads.h"
+#include "variable.h"
+#include "vectors.h"
 
-#include "libguile/async.h"
-#include "libguile/eval.h"
-#include "libguile/vectors.h"
-#include "libguile/threads.h"
-
-#include "libguile/validate.h"
-#include "libguile/scmsigs.h"
+#include "scmsigs.h"
 
 
 
@@ -92,7 +100,7 @@ static SCM signal_handler_asyncs;
 static SCM signal_handler_threads;
 
 /* The signal delivery thread.  */
-scm_i_thread *scm_i_signal_delivery_thread = NULL;
+scm_thread *scm_i_signal_delivery_thread = NULL;
 
 /* The mutex held when launching the signal delivery thread.  */
 static scm_i_pthread_mutex_t signal_delivery_thread_mutex =
@@ -225,7 +233,7 @@ static SIGRETTYPE
 take_signal (int signum)
 {
   SCM cell = SCM_SIMPLE_VECTOR_REF (signal_handler_asyncs, signum);
-  scm_i_thread *t = SCM_I_CURRENT_THREAD;
+  scm_thread *t = SCM_I_CURRENT_THREAD;
 
   if (scm_is_false (SCM_CDR (cell)))
     {
@@ -327,11 +335,7 @@ SCM_DEFINE (scm_sigaction_for_thread, "sigaction", 1, 3, 0,
   if (SCM_UNBNDP (thread))
     thread = scm_current_thread ();
   else
-    {
-      SCM_VALIDATE_THREAD (4, thread);
-      if (scm_c_thread_exited_p (thread))
-	SCM_MISC_ERROR ("thread has already exited", SCM_EOL);
-    }
+    SCM_VALIDATE_THREAD (4, thread);
 
   scm_i_ensure_signal_delivery_thread ();
 
@@ -558,7 +562,13 @@ SCM_DEFINE (scm_setitimer, "setitimer", 5, 0, 0,
             "The return value will be a list of two cons pairs representing the\n"
             "current state of the given timer.  The first pair is the seconds and\n"
             "microseconds of the timer @code{it_interval}, and the second pair is\n"
-            "the seconds and microseconds of the timer @code{it_value}.")
+            "the seconds and microseconds of the timer @code{it_value}."
+	    "\n"
+	    "@code{ITIMER_PROF} or @code{ITIMER_VIRTUAL} are not supported on\n"
+	    "some platforms and will always error. @code{(provided? 'ITIMER_PROF)}\n"
+	    "and @code{(provided? 'ITIMER_VIRTUAL)} report whether those timers\n"
+	    "are supported.\n")
+
 #define FUNC_NAME s_scm_setitimer
 {
   int rv;
@@ -595,7 +605,12 @@ SCM_DEFINE (scm_getitimer, "getitimer", 1, 0, 0,
             "The return value will be a list of two cons pairs representing the\n"
             "current state of the given timer.  The first pair is the seconds and\n"
             "microseconds of the timer @code{it_interval}, and the second pair is\n"
-            "the seconds and microseconds of the timer @code{it_value}.")
+            "the seconds and microseconds of the timer @code{it_value}."
+	    "\n"
+	    "@code{ITIMER_PROF} or @code{ITIMER_VIRTUAL} are not supported on\n"
+	    "some platforms and will always error. @code{(provided? 'ITIMER_PROF)}\n"
+	    "and @code{(provided? 'ITIMER_VIRTUAL)} report whether those timers\n"
+	    "are supported.\n")
 #define FUNC_NAME s_scm_getitimer
 {
   int rv;
@@ -605,10 +620,10 @@ SCM_DEFINE (scm_getitimer, "getitimer", 1, 0, 0,
   c_which_timer = SCM_NUM2INT(1, which_timer);
 
   SCM_SYSCALL(rv = getitimer(c_which_timer, &old_timer));
-  
+
   if(rv != 0)
     SCM_SYSERROR;
-  
+
   return scm_list_2 (scm_cons (scm_from_long (old_timer.it_interval.tv_sec),
 			       scm_from_long (old_timer.it_interval.tv_usec)),
 		     scm_cons (scm_from_long (old_timer.it_value.tv_sec),
@@ -730,14 +745,14 @@ scm_init_scmsigs ()
   scm_c_define ("ITIMER_REAL", scm_from_int (ITIMER_REAL));
   scm_c_define ("ITIMER_VIRTUAL", scm_from_int (ITIMER_VIRTUAL));
   scm_c_define ("ITIMER_PROF", scm_from_int (ITIMER_PROF));
+#ifdef HAVE_USABLE_GETITIMER_PROF
+  scm_add_feature ("ITIMER_PROF");
+#endif
+#ifdef HAVE_USABLE_GETITIMER_VIRTUAL
+  scm_add_feature ("ITIMER_VIRTUAL");
+#endif
 #endif /* defined(HAVE_SETITIMER) || defined(HAVE_GETITIMER) */
 
-#include "libguile/scmsigs.x"
+#include "scmsigs.x"
 }
 
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
