@@ -1,22 +1,23 @@
 /* srfi-13.c --- SRFI-13 procedures for Guile
- *
- * Copyright (C) 2001, 2004, 2005, 2006, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+
+   Copyright 2001,2004-2006,2008-2012,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 #ifdef HAVE_CONFIG_H
@@ -27,11 +28,20 @@
 #include <unicase.h>
 #include <unictype.h>
 
-#include "libguile.h"
+#include "deprecation.h"
+#include "error.h"
+#include "eval.h"
+#include "gsubr.h"
+#include "hash.h"
+#include "list.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "procs.h"
+#include "srfi-14.h"
+#include "symbols.h"
+
+#include "srfi-13.h"
 
-#include <libguile/deprecation.h>
-#include "libguile/srfi-13.h"
-#include "libguile/srfi-14.h"
 
 #define MY_VALIDATE_SUBSTRING_SPEC(pos_str, str,              \
                                    pos_start, start, c_start, \
@@ -3112,22 +3122,6 @@ SCM_DEFINE (scm_string_filter, "string-filter", 2, 2, 0,
   SCM result;
   size_t idx;
 
-#if SCM_ENABLE_DEPRECATED == 1
-  if (scm_is_string (char_pred))
-    {
-      SCM tmp;
-
-      scm_c_issue_deprecation_warning
-        ("Guile used to use the wrong argument order for string-filter.\n"
-         "This call to string-filter had the arguments in the wrong order.\n"
-         "See SRFI-13 for more details. At some point we will remove this hack.");
-
-      tmp = char_pred;
-      char_pred = s;
-      s = tmp;
-    }
-#endif
-
   MY_VALIDATE_SUBSTRING_SPEC (2, s,
 			      3, start, cstart,
 			      4, end, cend);
@@ -3245,22 +3239,6 @@ SCM_DEFINE (scm_string_delete, "string-delete", 2, 2, 0,
   SCM result;
   size_t idx;
 
-#if SCM_ENABLE_DEPRECATED == 1
-  if (scm_is_string (char_pred))
-    {
-      SCM tmp;
-
-      scm_c_issue_deprecation_warning
-        ("Guile used to use the wrong argument order for string-delete.\n"
-         "This call to string-filter had the arguments in the wrong order.\n"
-         "See SRFI-13 for more details. At some point we will remove this hack.");
-
-      tmp = char_pred;
-      char_pred = s;
-      s = tmp;
-    }
-#endif
-
   MY_VALIDATE_SUBSTRING_SPEC (2, s,
 			      3, start, cstart,
 			      4, end, cend);
@@ -3384,7 +3362,7 @@ SCM_DEFINE (scm_string_delete, "string-delete", 2, 2, 0,
 void
 scm_init_srfi_13 (void)
 {
-#include "libguile/srfi-13.x"
+#include "srfi-13.x"
 }
 
 /* End of srfi-13.c.  */
