@@ -1,38 +1,52 @@
 /* srfi-14.c --- SRFI-14 procedures for Guile
- *
- * Copyright (C) 2001, 2004, 2006, 2007, 2009, 2011 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+
+   Copyright 2001,2004,2006-2007,2009,2011,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
-
+#include <stdio.h>
 #include <string.h>
 #include <unictype.h>
 
-#include "libguile.h"
-#include "libguile/srfi-14.h"
-#include "libguile/strings.h"
-#include "libguile/chars.h"
+#include "boolean.h"
+#include "chars.h"
+#include "eval.h"
+#include "gsubr.h"
+#include "list.h"
+#include "modules.h"
+#include "numbers.h"
+#include "pairs.h"
+#include "ports.h"
+#include "procs.h"
+#include "smob.h"
+#include "strings.h"
+#include "symbols.h"
+#include "values.h"
+
+#include "srfi-14.h"
+
 
 /* Include the pre-computed standard charset data.  */
-#include "libguile/srfi-14.i.c"
+#include "srfi-14.i.c"
 
 scm_t_char_range cs_full_ranges[] = {
   {0x0000, SCM_CODEPOINT_SURROGATE_START - 1}
@@ -597,27 +611,27 @@ charset_print (SCM charset, SCM port, scm_print_state *pstate SCM_UNUSED)
 
   p = SCM_CHARSET_DATA (charset);
 
-  scm_puts_unlocked ("#<charset {", port);
+  scm_puts ("#<charset {", port);
   for (i = 0; i < p->len; i++)
     {
       if (first)
         first = 0;
       else
-        scm_puts_unlocked (" ", port);
+        scm_puts (" ", port);
       scm_write (SCM_MAKE_CHAR (p->ranges[i].lo), port);
       if (p->ranges[i].lo != p->ranges[i].hi)
         {
-          scm_puts_unlocked ("..", port);
+          scm_puts ("..", port);
           scm_write (SCM_MAKE_CHAR (p->ranges[i].hi), port);
         }
       if (i >= max_ranges_to_print)
         {
           /* Too many to print here.  Quit early.  */
-          scm_puts_unlocked (" ...", port);
+          scm_puts (" ...", port);
           break;
         }
     }
-  scm_puts_unlocked ("}>", port);
+  scm_puts ("}>", port);
   return 1;
 }
 
@@ -630,16 +644,16 @@ charset_cursor_print (SCM cursor, SCM port,
 
   cur = (scm_t_char_set_cursor *) SCM_SMOB_DATA (cursor);
 
-  scm_puts_unlocked ("#<charset-cursor ", port);
+  scm_puts ("#<charset-cursor ", port);
   if (cur->range == (size_t) (-1))
-    scm_puts_unlocked ("(empty)", port);
+    scm_puts ("(empty)", port);
   else
     {
       scm_write (scm_from_size_t (cur->range), port);
-      scm_puts_unlocked (":", port);
+      scm_puts (":", port);
       scm_write (scm_from_int32 (cur->n), port);
     }
-  scm_puts_unlocked (">", port);
+  scm_puts (">", port);
   return 1;
 }
 
@@ -1886,7 +1900,7 @@ SCM_DEFINE (scm_char_set_diff_plus_intersection, "char-set-diff+intersection", 1
       charsets_intersection (p, r);
       rest = SCM_CDR (rest);
     }
-  return scm_values (scm_list_2 (res1, res2));
+  return scm_values_2 (res1, res2);
 }
 #undef FUNC_NAME
 
@@ -1974,7 +1988,7 @@ SCM_DEFINE (scm_char_set_diff_plus_intersection_x,
     scm_char_set_intersection (scm_cons (cs1, scm_cons (cs2, rest)));
   cs1 = diff;
   cs2 = intersect;
-  return scm_values (scm_list_2 (cs1, cs2));
+  return scm_values_2 (cs1, cs2);
 }
 #undef FUNC_NAME
 
@@ -2031,7 +2045,7 @@ SCM_DEFINE (scm_sys_char_set_dump, "%char-set-dump", 1, 0, 0, (SCM charset),
   SCM ranges = SCM_EOL, elt;
   size_t i;
   scm_t_char_set *cs;
-  char codepoint_string_lo[9], codepoint_string_hi[9];
+  char codepoint_string_lo[13], codepoint_string_hi[13];
 
   SCM_VALIDATE_SMOB (1, charset, charset);
   cs = SCM_CHARSET_DATA (charset);
@@ -2105,7 +2119,7 @@ scm_init_srfi_14 (void)
   scm_char_set_designated = define_charset ("char-set:designated", &cs_designated);
   scm_char_set_full = define_charset ("char-set:full", &cs_full);
 
-#include "libguile/srfi-14.x"
+#include "srfi-14.x"
 }
 
 /* End of srfi-14.c.  */
