@@ -1,21 +1,21 @@
-/* Copyright (C) 1995, 1996, 1998, 1999, 2000, 2001, 2002, 2003, 2005, 2006,
- *   2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301 USA
- */
+/* Copyright 1995,1996,1998-2003,2005-2006,2009-2014,2018
+     Free Software Foundation, Inc.
+
+   This file is part of Guile.
+
+   Guile is free software: you can redistribute it and/or modify it
+   under the terms of the GNU Lesser General Public License as published
+   by the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Guile is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+   License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with Guile.  If not, see
+   <https://www.gnu.org/licenses/>.  */
 
 
 
@@ -24,26 +24,28 @@
 #  include <config.h>
 #endif
 
-#include "libguile/_scm.h"
-
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 
-#include "libguile/bytevectors.h"
-#include "libguile/eval.h"
-#include "libguile/ports.h"
-#include "libguile/read.h"
-#include "libguile/strings.h"
-#include "libguile/modules.h"
-#include "libguile/validate.h"
-#include "libguile/deprecation.h"
-#include "libguile/srfi-4.h"
+#include "bytevectors.h"
+#include "deprecation.h"
+#include "eval.h"
+#include "gsubr.h"
+#include "keywords.h"
+#include "modules.h"
+#include "ports.h"
+#include "procs.h"
+#include "read.h"
+#include "srfi-4.h"
+#include "strings.h"
+#include "symbols.h"
+#include "syscalls.h"
+#include "threads.h"
+#include "variable.h"
 
-#include "libguile/strports.h"
+#include "strports.h"
 
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
 
 
 
@@ -80,6 +82,8 @@ string_port_read (SCM port, SCM dst, size_t start, size_t count)
   return count;
 }
 
+#define MAX(A, B) ((A) >= (B) ? (A) : (B))
+
 static size_t
 string_port_write (SCM port, SCM src, size_t start, size_t count)
 {
@@ -90,7 +94,7 @@ string_port_write (SCM port, SCM src, size_t start, size_t count)
       SCM new_bv;
       size_t new_size;
 
-      new_size = max (SCM_BYTEVECTOR_LENGTH (stream->bytevector) * 2,
+      new_size = MAX (SCM_BYTEVECTOR_LENGTH (stream->bytevector) * 2,
                       stream->pos + count);
       new_bv = scm_c_make_bytevector (new_size);
       memcpy (SCM_BYTEVECTOR_CONTENTS (new_bv),
@@ -134,6 +138,18 @@ string_port_seek (SCM port, scm_t_off offset, int whence)
 }
 #undef FUNC_NAME
 
+static void
+string_port_truncate (SCM port, scm_t_off length)
+#define FUNC_NAME "string_port_truncate"
+{
+  struct string_port *stream = (void *) SCM_STREAM (port);
+
+  if (0 <= length && stream->pos <= length && length <= stream->len)
+    stream->len = length;
+  else
+    scm_out_of_range (FUNC_NAME, scm_from_off_t_or_off64_t (length));
+}
+#undef FUNC_NAME
 
 
 /* The initial size in bytes of a string port's buffer.  */
@@ -372,6 +388,7 @@ scm_make_string_port_type ()
                                               string_port_read,
                                               string_port_write);
   scm_set_port_seek (ptob, string_port_seek);
+  scm_set_port_truncate (ptob, string_port_truncate);
 
   return ptob;
 }
@@ -381,12 +398,6 @@ scm_init_strports ()
 {
   scm_string_port_type = scm_make_string_port_type ();
 
-#include "libguile/strports.x"
+#include "strports.x"
 }
 
-
-/*
-  Local Variables:
-  c-file-style: "gnu"
-  End:
-*/
