@@ -1,6 +1,6 @@
 ;;; Continuation-passing style (CPS) intermediate language (IL)
 
-;; Copyright (C) 2013, 2014, 2015 Free Software Foundation, Inc.
+;; Copyright (C) 2013, 2014, 2015, 2017, 2018 Free Software Foundation, Inc.
 
 ;;;; This library is free software; you can redistribute it and/or
 ;;;; modify it under the terms of the GNU Lesser General Public
@@ -46,7 +46,6 @@
             fixpoint
 
             ;; Flow analysis.
-            compute-constant-values
             compute-function-body
             compute-reachable-functions
             compute-successors
@@ -124,9 +123,9 @@ member, or @code{#f} otherwise."
 
 (define (intmap-map proc map)
   (persistent-intmap
-   (intmap-fold (lambda (k v out) (intmap-replace! out k (proc k v)))
+   (intmap-fold (lambda (k v out) (intmap-add! out k (proc k v)))
                 map
-                map)))
+                empty-intmap)))
 
 (define (intmap-keys map)
   "Return an intset of the keys in @var{map}."
@@ -180,33 +179,6 @@ disjoint, an error will be signalled."
                (values x0* x1*)
                (lp x0* x1*))))))))
 
-(define (compute-defining-expressions conts)
-  (define (meet-defining-expressions old new)
-    ;; If there are multiple definitions, punt and
-    ;; record #f.
-    #f)
-  (persistent-intmap
-   (intmap-fold (lambda (label cont defs)
-                  (match cont
-                    (($ $kargs _ _ ($ $continue k src exp))
-                     (match (intmap-ref conts k)
-                       (($ $kargs (_) (var))
-                        (intmap-add! defs var exp meet-defining-expressions))
-                       (_ defs)))
-                    (_ defs)))
-                conts
-                empty-intmap)))
-
-(define (compute-constant-values conts)
-  (persistent-intmap
-   (intmap-fold (lambda (var exp out)
-                  (match exp
-                    (($ $const val)
-                     (intmap-add! out var val))
-                    (_ out)))
-                (compute-defining-expressions conts)
-                empty-intmap)))
-
 (define (compute-function-body conts kfun)
   (persistent-intset
    (let visit-cont ((label kfun) (labels empty-intset))
@@ -226,13 +198,16 @@ disjoint, an error will be signalled."
             (if kalt
                 (visit-cont kalt (visit-cont kbody labels))
                 (visit-cont kbody labels)))
-           (($ $kargs names syms ($ $continue k src exp))
-            (visit-cont k (match exp
-                            (($ $branch k)
-                             (visit-cont k labels))
-                            (($ $prompt escape? tag k)
-                             (visit-cont k labels))
-                            (_ labels)))))))))))
+           (($ $kargs names syms term)
+            (match term
+              (($ $continue k)
+               (visit-cont k labels))
+              (($ $branch kf kt)
+               (visit-cont kf (visit-cont kt labels)))
+              (($ $prompt k kh)
+               (visit-cont k (visit-cont kh labels)))
+              (($ $throw)
+               labels))))))))))
 
 (define* (compute-reachable-functions conts #:optional (kfun 0))
   "Compute a mapping LABEL->LABEL..., where each key is a reachable
@@ -250,7 +225,8 @@ intset."
           (match exp
             (($ $fun label) (return1 label))
             (($ $rec _ _ (($ $fun labels) ...)) (return labels))
-            (($ $closure label nfree) (return1 label))
+            (($ $const-fun label) (return1 label))
+            (($ $code label) (return1 label))
             (($ $callk label) (return1 label))
             (_ (return0))))
          (_ (return0))))
@@ -285,11 +261,12 @@ intset."
       (if (intmap-ref succs label (lambda (_) #f))
           succs
           (match (intmap-ref conts label)
-            (($ $kargs names vars ($ $continue k src exp))
-             (match exp
-               (($ $branch kt) (propagate2 k kt))
-               (($ $prompt escape? tag handler) (propagate2 k handler))
-               (_ (propagate1 k))))
+            (($ $kargs names vars term)
+             (match term
+               (($ $continue k) (propagate1 k))
+               (($ $branch kf kt) (propagate2 kf kt))
+               (($ $prompt k kh) (propagate2 k kh))
+               (($ $throw) (propagate0))))
             (($ $kreceive arity k)
              (propagate1 k))
             (($ $kfun src meta self tail clause)
@@ -319,12 +296,12 @@ intset."
        preds)
       (($ $kclause arity kbody kalt)
        (add-pred kbody (if kalt (add-pred kalt preds) preds)))
-      (($ $kargs names syms ($ $continue k src exp))
-       (add-pred k
-                 (match exp
-                   (($ $branch k) (add-pred k preds))
-                   (($ $prompt _ _ k) (add-pred k preds))
-                   (_ preds))))))
+      (($ $kargs names syms term)
+       (match term
+         (($ $continue k)   (add-pred k preds))
+         (($ $branch kf kt) (add-pred kf (add-pred kt preds)))
+         (($ $prompt k kh)  (add-pred k (add-pred kh preds)))
+         (($ $throw)        preds)))))
   (persistent-intmap
    (intset-fold add-preds labels
                 (intset->intmap (lambda (label) '()) labels))))
