@@ -1,6 +1,6 @@
 ;;; open-coding primitive procedures
 
-;; Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015 Free Software Foundation, Inc.
+;; Copyright (C) 2009-2015, 2017-2018 Free Software Foundation, Inc.
 
 ;;;; This library is free software; you can redistribute it and/or
 ;;;; modify it under the terms of the GNU Lesser General Public
@@ -21,6 +21,7 @@
 (define-module (language tree-il primitives)
   #:use-module (system base pmatch)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 threads)
   #:use-module (rnrs bytevectors)
   #:use-module (system base syntax)
   #:use-module (language tree-il)
@@ -53,9 +54,12 @@
     pair? null? list? symbol? vector? string? struct? number? char? nil?
     bytevector? keyword? bitvector?
 
+    symbol->string string->symbol
+
     procedure? thunk?
 
     complex? real? rational? inf? nan? integer? exact? inexact? even? odd?
+    exact-integer?
 
     char<? char<=? char>=? char>?
 
@@ -83,7 +87,7 @@
 
     current-module define!
 
-    current-thread fluid-ref fluid-set! with-fluid*
+    current-thread fluid-ref fluid-set! with-fluid* with-dynamic-state
 
     call-with-prompt
     abort-to-prompt* abort-to-prompt
@@ -93,7 +97,7 @@
 
     string-length string-ref string-set!
 
-    allocate-struct struct-vtable make-struct struct-ref struct-set!
+    make-struct/simple struct-vtable struct-ref struct-set!
 
     bytevector-length
 
@@ -138,7 +142,7 @@
 (define *primitive-constructors*
   ;; Primitives that return a fresh object.
   '(acons cons cons* list vector make-vector
-    allocate-struct make-struct make-struct/no-tail
+    make-struct/simple
     make-prompt-tag))
 
 (define *primitive-accessors*
@@ -173,8 +177,10 @@
     symbol? variable? vector? struct? string? number? char?
     bytevector? keyword? bitvector? atomic-box?
     complex? real? rational? inf? nan? integer? exact? inexact? even? odd?
+    exact-integer?
     char<? char<=? char>=? char>?
     integer->char char->integer number->string string->number
+    symbol->string string->symbol
     struct-vtable
     length string-length vector-length bytevector-length
     ;; These all should get expanded out by expand-primitives.
@@ -193,6 +199,7 @@
     not
     pair? null? nil? list?
     symbol? variable? vector? struct? string? number? char?
+    exact-integer?
     bytevector? keyword? bitvector?
     procedure? thunk? atomic-box?
     acons cons cons* list vector))
@@ -377,6 +384,43 @@
                                     ,(consequent (cadr in)))
                                   out)))))))
 
+;; Oddly, scm-error is just an explicitly 5-argument `throw'.  Weird.
+(define-primitive-expander scm-error (key who message args data)
+  (throw key who message args data))
+
+(define (escape-format-directives str)
+  (string-join (string-split str #\~) "~~"))
+
+(hashq-set!
+ *primitive-expand-table*
+ 'error
+ (match-lambda*
+  ((src)
+   (make-primcall src 'throw
+                  (list (make-const src 'misc-error)
+                        (make-const src #f)
+                        (make-const src "?")
+                        (make-const src #f)
+                        (make-const src #f))))
+  ((src ($ <const> src2 (? string? message)) . args)
+   (let ((msg (string-join (cons (escape-format-directives message)
+                                 (make-list (length args) "~S")))))
+     (make-primcall src 'throw
+                    (list (make-const src 'misc-error)
+                          (make-const src #f)
+                          (make-const src2 msg)
+                          (make-primcall src 'list args)
+                          (make-const src #f)))))
+  ((src message . args)
+   (let ((msg (string-join (cons "~A" (make-list (length args) "~S")))))
+     (make-primcall src 'throw
+                    (list (make-const src 'misc-error)
+                          (make-const src #f)
+                          (make-const src msg)
+                          (make-const src "?")
+                          (make-primcall src 'list (cons message args))
+                          (make-const src #f)))))))
+
 (define-primitive-expander zero? (x)
   (= x 0))
 
@@ -426,6 +470,17 @@
   (x y) (logand x y)
   (x y z ... last) (logand (logand x y . z) last))
 
+(hashq-set!
+ *primitive-expand-table*
+ 'make-vector
+ (match-lambda*
+  ((src len)
+   (make-primcall src 'make-vector (list len (make-const src *unspecified*))))
+  ((src len init)
+   (make-primcall src 'make-vector (list len init)))
+  ((src . args)
+   (make-call src (make-primitive-ref src 'make-vector) args))))
+
 (define-primitive-expander caar (x) (car (car x)))
 (define-primitive-expander cadr (x) (car (cdr x)))
 (define-primitive-expander cdar (x) (cdr (car x)))
@@ -466,13 +521,6 @@
 (define-primitive-expander call/cc (proc)
   (call-with-current-continuation proc))
 
-(define-primitive-expander make-struct (vtable tail-size . args)
-  (if (and (const? tail-size)
-           (let ((n (const-exp tail-size)))
-             (and (number? n) (exact? n) (zero? n))))
-      (make-struct/no-tail vtable . args)
-      #f))
-
 (define-primitive-expander u8vector-ref (vec i)
   (bytevector-u8-ref vec i))
 (define-primitive-expander u8vector-set! (vec i x)
